@@ -107,9 +107,21 @@ INVALIDPARAMETER_FILTERVALUESNOTLIST = 'InvalidParameter.FilterValuesNotList'
 # 该过滤规则不合法。
 INVALIDPARAMETER_INVALIDFILTER = 'InvalidParameter.InvalidFilter'
 
+# 指定参数值不是预期的字典格式。
+INVALIDPARAMETER_INVALIDKEY = 'InvalidParameter.InvalidKey'
+
 # 下一跳类型与下一跳网关不匹配。
 INVALIDPARAMETER_NEXTHOPMISMATCH = 'InvalidParameter.NextHopMismatch'
 
+# 指定参数值不是键值对。
+INVALIDPARAMETER_NOTDICT = 'InvalidParameter.NotDict'
+
+# 指定参数值不是一个列表。
+INVALIDPARAMETER_NOTLIST = 'InvalidParameter.NotList'
+
+# 指定键值不是一个字符串型。
+INVALIDPARAMETER_NOTSTR = 'InvalidParameter.NotStr'
+
 # 专线网关跨可用区容灾组不存在。
 INVALIDPARAMETER_VPGHAGROUPNOTFOUND = 'InvalidParameter.VpgHaGroupNotFound'
 
@@ -209,6 +221,9 @@ INVALIDPARAMETERVALUE_IPV6RULENOTCHANGE = 'InvalidParameterValue.IPv6RuleNotChan
 # 资源格式错误
 INVALIDPARAMETERVALUE_ILLEGAL = 'InvalidParameterValue.Illegal'
 
+# 不能在VPC CIDR范围内。
+INVALIDPARAMETERVALUE_INVPCCIDR = 'InvalidParameterValue.InVpcCidr'
+
 # 该实例的计费方式与其他实例不同。
 INVALIDPARAMETERVALUE_INCONSISTENTINSTANCEINTERNETCHARGETYPE = 'InvalidParameterValue.InconsistentInstanceInternetChargeType'
 
@@ -326,12 +341,27 @@ INVALIDPARAMETERVALUE_NETWORKINTERFACEIDMALFORMED = 'InvalidParameterValue.Netwo
 # 未找到网络接口ID，或私有IP地址未在网络接口配置。
 INVALIDPARAMETERVALUE_NETWORKINTERFACENOTFOUND = 'InvalidParameterValue.NetworkInterfaceNotFound'
 
+# 必须在VPC CIDR范围内。
+INVALIDPARAMETERVALUE_NOTINVPCCIDR = 'InvalidParameterValue.NotInVpcCidr'
+
+# 不是UTF8编码。
+INVALIDPARAMETERVALUE_NOTUTF8ENCODINGERROR = 'InvalidParameterValue.NotUtf8EncodingError'
+
 # 该操作仅对主网卡支持。
 INVALIDPARAMETERVALUE_ONLYSUPPORTEDFORMASTERNETWORKCARD = 'InvalidParameterValue.OnlySupportedForMasterNetworkCard'
 
 # 参数值格式不匹配。
 INVALIDPARAMETERVALUE_PARAMETERMISMATCH = 'InvalidParameterValue.ParameterMismatch'
 
+# 私网NAT网关不存在
+INVALIDPARAMETERVALUE_PRIVATENATNOTEXISTS = 'InvalidParameterValue.PrivateNatNotExists'
+
+# 私网NAT网关规则不存在。
+INVALIDPARAMETERVALUE_PRIVATENATRULENOTEXISTS = 'InvalidParameterValue.PrivateNatRuleNotExists'
+
+# 私网NAT网关传入规则类型不支持。
+INVALIDPARAMETERVALUE_PRIVATENATSNATRULENOTSUPPORT = 'InvalidParameterValue.PrivateNatSnatRuleNotSupport'
+
 # 参数值不在指定范围。
 INVALIDPARAMETERVALUE_RANGE = 'InvalidParameterValue.Range'
 
@@ -509,6 +539,12 @@ LIMITEXCEEDED_BANDWIDTHPACKAGEQUOTA = 'LimitExceeded.BandwidthPackageQuota'
 # 当前带宽包加入资源上限。
 LIMITEXCEEDED_BANDWIDTHPACKAGERESOURCEQUOTA = 'LimitExceeded.BandwidthPackageResourceQuota'
 
+# 云联网路由传播策略数量已达到上限。
+LIMITEXCEEDED_CCNROUTEBROADCASTPOLICY = 'LimitExceeded.CcnRouteBroadcastPolicy'
+
+# 云联网路由传播策略条件数量已达到上限。
+LIMITEXCEEDED_CCNROUTEBROADCASTPOLICYCOND = 'LimitExceeded.CcnRouteBroadcastPolicyCond'
+
 # 超过更换IP配额。
 LIMITEXCEEDED_CHANGEADDRESSQUOTA = 'LimitExceeded.ChangeAddressQuota'
 
@@ -524,6 +560,9 @@ LIMITEXCEEDED_DAILYALLOCATEADDRESSQUOTALIMITEXCEEDED = 'LimitExceeded.DailyAlloc
 # 超过每日更换IP配额。
 LIMITEXCEEDED_DAILYCHANGEADDRESSQUOTA = 'LimitExceeded.DailyChangeAddressQuota'
 
+# 默认VPC数量已达到上限。
+LIMITEXCEEDED_DEFAULTVPCLIMITEXCEEDED = 'LimitExceeded.DefaultVpcLimitExceeded'
+
 # 实例绑定的弹性IP超过配额。
 LIMITEXCEEDED_INSTANCEADDRESSQUOTA = 'LimitExceeded.InstanceAddressQuota'
 
@@ -548,6 +587,12 @@ LIMITEXCEEDED_NETWORKINTERFACELIMITEXCEEDED = 'LimitExceeded.NetworkInterfaceLim
 # 过滤参数名称超过限制。
 LIMITEXCEEDED_NUMBEROFFILTERS = 'LimitExceeded.NumberOfFilters'
 
+# 私网NAT网关转换规则的访问控制规则数量达到上限。
+LIMITEXCEEDED_PRIVATENATTRANSLATIONACLRULE = 'LimitExceeded.PrivateNatTranslationAclRule'
+
+# 私网NAT网关的转换数量达到上限。
+LIMITEXCEEDED_PRIVATENATTRANSLATIONNATRULE = 'LimitExceeded.PrivateNatTranslationNatRule'
+
 # NAT网关绑定的弹性IP超过上限。
 LIMITEXCEEDED_PUBLICIPADDRESSPERNATGATEWAYLIMITEXCEEDED = 'LimitExceeded.PublicIpAddressPerNatGatewayLimitExceeded'
 
@@ -701,6 +746,9 @@ UNSUPPORTEDOPERATION_BINDEIP = 'UnsupportedOperation.BindEIP'
 # 指定VPC CIDR范围不支持私有网络和基础网络设备互通。
 UNSUPPORTEDOPERATION_CIDRUNSUPPORTEDCLASSICLINK = 'UnsupportedOperation.CIDRUnSupportedClassicLink'
 
+# 路由表选择策略不支持默认路由表。
+UNSUPPORTEDOPERATION_CANNOTASSIGNDEFAULTROUTETABLE = 'UnsupportedOperation.CanNotAssignDefaultRouteTable'
+
 # 实例已关联CCN。
 UNSUPPORTEDOPERATION_CCNATTACHED = 'UnsupportedOperation.CcnAttached'
 
@@ -716,6 +764,9 @@ UNSUPPORTEDOPERATION_CCNINSTANCEACCOUNTNOTAPPROVEDBYUNICOM = 'UnsupportedOperati
 # 实例未关联CCN。
 UNSUPPORTEDOPERATION_CCNNOTATTACHED = 'UnsupportedOperation.CcnNotAttached'
 
+# 当前云联网未开启路由传播策略。
+UNSUPPORTEDOPERATION_CCNNOTENABLEBROADCASTPOLICY = 'UnsupportedOperation.CcnNotEnableBroadcastPolicy'
+
 # 跨账号场景下不支持自驾云账号实例 关联普通账号云联网。
 UNSUPPORTEDOPERATION_CCNORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.CcnOrdinaryAccountRefuseAttach'
 
@@ -818,6 +869,9 @@ UNSUPPORTEDOPERATION_INSTANCECDCIDNOTMATCHCCNCDCID = 'UnsupportedOperation.Insta
 # 指定实例资源不匹配。
 UNSUPPORTEDOPERATION_INSTANCEMISMATCH = 'UnsupportedOperation.InstanceMismatch'
 
+# 路由表选择策略配置的实例不存在。
+UNSUPPORTEDOPERATION_INSTANCENOTEXIST = 'UnsupportedOperation.InstanceNotExist'
+
 # 跨账号场景下不支持普通账号实例关联自驾云账号云联网。
 UNSUPPORTEDOPERATION_INSTANCEORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.InstanceOrdinaryAccountRefuseAttach'
 
@@ -917,12 +971,24 @@ UNSUPPORTEDOPERATION_NOTPOSTPAIDCCNOPERATION = 'UnsupportedOperation.NotPostpaid
 # 当前云联网不支持同时关联EDGE实例和跨境实例
 UNSUPPORTEDOPERATION_NOTSUPPORTATTACHEDGEANDCROSSBORDERINSTANCE = 'UnsupportedOperation.NotSupportAttachEdgeAndCrossBorderInstance'
 
+# 没有开启多路由表特性，不能创建用户路由表。
+UNSUPPORTEDOPERATION_NOTSUPPORTCREATECCNROUTETABLE = 'UnsupportedOperation.NotSupportCreateCcnRouteTable'
+
+# 默认路由表，不支持删除。
+UNSUPPORTEDOPERATION_NOTSUPPORTDELETEDEFAULTCCNROUTETABLE = 'UnsupportedOperation.NotSupportDeleteDefaultCcnRouteTable'
+
 # 不支持删除默认路由表。
 UNSUPPORTEDOPERATION_NOTSUPPORTDELETEDEFAULTROUTETABLE = 'UnsupportedOperation.NotSupportDeleteDefaultRouteTable'
 
 # 公有云到黑石的对等连接不支持删除。
 UNSUPPORTEDOPERATION_NOTSUPPORTDELETEVPCBMPEER = 'UnsupportedOperation.NotSupportDeleteVpcBmPeer'
 
+# 默认路由表，不支持修改。
+UNSUPPORTEDOPERATION_NOTSUPPORTMODIFYDEFAULTCCNROUTETABLE = 'UnsupportedOperation.NotSupportModifyDefaultCcnRouteTable'
+
+# 不支持编辑相同的实例和源地址。
+UNSUPPORTEDOPERATION_NOTSUPPORTSAMECCNINSTANCEANDSOURCEADDRESS = 'UnsupportedOperation.NotSupportSameCcnInstanceAndSourceAddress'
+
 # 不支持的可用区
 UNSUPPORTEDOPERATION_NOTSUPPORTZONE = 'UnsupportedOperation.NotSupportZone'
 
@@ -950,6 +1016,9 @@ UNSUPPORTEDOPERATION_PREPAIDCCNONLYSUPPORTINTERREGIONLIMIT = 'UnsupportedOperati
 # 指定的值是主IP。
 UNSUPPORTEDOPERATION_PRIMARYIP = 'UnsupportedOperation.PrimaryIp'
 
+# 私网NAT网关存在关联规则。
+UNSUPPORTEDOPERATION_PRIVATENATGATEWAYASSOCIATIONEXISTS = 'UnsupportedOperation.PrivateNatGatewayAssociationExists'
+
 # Nat网关至少存在一个弹性IP，弹性IP不能解绑。
 UNSUPPORTEDOPERATION_PUBLICIPADDRESSDISASSOCIATE = 'UnsupportedOperation.PublicIpAddressDisassociate'
 
@@ -983,9 +1052,15 @@ UNSUPPORTEDOPERATION_ROLENOTFOUND = 'UnsupportedOperation.RoleNotFound'
 # 当前路由表删除失败，请先检查是否存在关联的策略。
 UNSUPPORTEDOPERATION_ROUTETABLECANNOTDELETE = 'UnsupportedOperation.RouteTableCanNotDelete'
 
+# 当前云联网的路由表数量已超过限制。
+UNSUPPORTEDOPERATION_ROUTETABLEEXCEEDPERVBCLIMIT = 'UnsupportedOperation.RouteTableExceedPerVbcLimit'
+
 # 路由表绑定了子网。
 UNSUPPORTEDOPERATION_ROUTETABLEHASSUBNETRULE = 'UnsupportedOperation.RouteTableHasSubnetRule'
 
+# 当前云联网的路由表选择策略数量已超过限制。
+UNSUPPORTEDOPERATION_ROUTETABLESELECTPOLICYEXCEED = 'UnsupportedOperation.RouteTableSelectPolicyExceed'
+
 # SslVpnClientIds：`vpnc-20f9b3d7` 证书状态已禁用或Client证书状态不可用，不支持禁用证书。
 UNSUPPORTEDOPERATION_SSLCLIENTCERTALREADYDISABLEORCERTABNORMAL = 'UnsupportedOperation.SSLClientCertAlreadyDisableOrCertAbnormal'
 
